/****************************************************************************
** Meta object code from reading C++ file 'collection-view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/file-io/collection-view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collection-view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__CollectionView_t {
    QByteArrayData data[15];
    char stringdata0[196];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__CollectionView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__CollectionView_t qt_meta_stringdata_Palapeli__CollectionView = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Palapeli::CollectionView"
QT_MOC_LITERAL(1, 25, 16), // "canDeleteChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 9), // "canDelete"
QT_MOC_LITERAL(4, 53, 16), // "canExportChanged"
QT_MOC_LITERAL(5, 70, 9), // "canExport"
QT_MOC_LITERAL(6, 80, 11), // "playRequest"
QT_MOC_LITERAL(7, 92, 17), // "Palapeli::Puzzle*"
QT_MOC_LITERAL(8, 110, 6), // "puzzle"
QT_MOC_LITERAL(9, 117, 15), // "handleActivated"
QT_MOC_LITERAL(10, 133, 5), // "index"
QT_MOC_LITERAL(11, 139, 22), // "handleSelectionChanged"
QT_MOC_LITERAL(12, 162, 17), // "sortMenuTriggered"
QT_MOC_LITERAL(13, 180, 8), // "QAction*"
QT_MOC_LITERAL(14, 189, 6) // "action"

    },
    "Palapeli::CollectionView\0canDeleteChanged\0"
    "\0canDelete\0canExportChanged\0canExport\0"
    "playRequest\0Palapeli::Puzzle*\0puzzle\0"
    "handleActivated\0index\0handleSelectionChanged\0"
    "sortMenuTriggered\0QAction*\0action"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__CollectionView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,
       6,    1,   50,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   53,    2, 0x08 /* Private */,
      11,    0,   56,    2, 0x08 /* Private */,
      12,    1,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 7,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void Palapeli::CollectionView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CollectionView *_t = static_cast<CollectionView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->canDeleteChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->canExportChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->playRequest((*reinterpret_cast< Palapeli::Puzzle*(*)>(_a[1]))); break;
        case 3: _t->handleActivated((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->handleSelectionChanged(); break;
        case 5: _t->sortMenuTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (CollectionView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionView::canDeleteChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CollectionView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionView::canExportChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CollectionView::*_t)(Palapeli::Puzzle * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionView::playRequest)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Palapeli::CollectionView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Palapeli__CollectionView.data,
      qt_meta_data_Palapeli__CollectionView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::CollectionView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::CollectionView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__CollectionView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Palapeli::CollectionView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Palapeli::CollectionView::canDeleteChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Palapeli::CollectionView::canExportChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Palapeli::CollectionView::playRequest(Palapeli::Puzzle * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
