/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/engine/view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__View_t {
    QByteArrayData data[29];
    char stringdata0[294];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__View_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__View_t qt_meta_stringdata_Palapeli__View = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Palapeli::View"
QT_MOC_LITERAL(1, 15, 16), // "zoomLevelChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 5), // "level"
QT_MOC_LITERAL(4, 39, 14), // "zoomAdjustable"
QT_MOC_LITERAL(5, 54, 10), // "adjustable"
QT_MOC_LITERAL(6, 65, 8), // "teleport"
QT_MOC_LITERAL(7, 74, 6), // "Piece*"
QT_MOC_LITERAL(8, 81, 1), // "p"
QT_MOC_LITERAL(9, 83, 5), // "scPos"
QT_MOC_LITERAL(10, 89, 5), // "View*"
QT_MOC_LITERAL(11, 95, 1), // "v"
QT_MOC_LITERAL(12, 97, 21), // "newPieceSelectionSeen"
QT_MOC_LITERAL(13, 119, 14), // "logSceneChange"
QT_MOC_LITERAL(14, 134, 1), // "r"
QT_MOC_LITERAL(15, 136, 8), // "setScene"
QT_MOC_LITERAL(16, 145, 16), // "Palapeli::Scene*"
QT_MOC_LITERAL(17, 162, 5), // "scene"
QT_MOC_LITERAL(18, 168, 14), // "moveViewportBy"
QT_MOC_LITERAL(19, 183, 10), // "sceneDelta"
QT_MOC_LITERAL(20, 194, 15), // "zoomSliderInput"
QT_MOC_LITERAL(21, 210, 6), // "zoomIn"
QT_MOC_LITERAL(22, 217, 7), // "zoomOut"
QT_MOC_LITERAL(23, 225, 6), // "zoomBy"
QT_MOC_LITERAL(24, 232, 5), // "delta"
QT_MOC_LITERAL(25, 238, 6), // "zoomTo"
QT_MOC_LITERAL(26, 245, 21), // "startVictoryAnimation"
QT_MOC_LITERAL(27, 267, 13), // "adjustPointer"
QT_MOC_LITERAL(28, 281, 12) // "viewportRect"

    },
    "Palapeli::View\0zoomLevelChanged\0\0level\0"
    "zoomAdjustable\0adjustable\0teleport\0"
    "Piece*\0p\0scPos\0View*\0v\0newPieceSelectionSeen\0"
    "logSceneChange\0r\0setScene\0Palapeli::Scene*\0"
    "scene\0moveViewportBy\0sceneDelta\0"
    "zoomSliderInput\0zoomIn\0zoomOut\0zoomBy\0"
    "delta\0zoomTo\0startVictoryAnimation\0"
    "adjustPointer\0viewportRect"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__View[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       1,  122, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       4,    1,   87,    2, 0x06 /* Public */,
       6,    3,   90,    2, 0x06 /* Public */,
      12,    1,   97,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,  100,    2, 0x0a /* Public */,
      15,    1,  103,    2, 0x0a /* Public */,
      18,    1,  106,    2, 0x0a /* Public */,
      20,    1,  109,    2, 0x0a /* Public */,
      21,    0,  112,    2, 0x0a /* Public */,
      22,    0,  113,    2, 0x0a /* Public */,
      23,    1,  114,    2, 0x0a /* Public */,
      25,    1,  117,    2, 0x0a /* Public */,
      26,    0,  120,    2, 0x08 /* Private */,
      27,    0,  121,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QPointF, 0x80000000 | 10,    8,    9,   11,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::QRectF,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, QMetaType::QPointF,   19,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      28, QMetaType::QRectF, 0x00095103,

       0        // eod
};

void Palapeli::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->zoomLevelChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->zoomAdjustable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->teleport((*reinterpret_cast< Piece*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2])),(*reinterpret_cast< View*(*)>(_a[3]))); break;
        case 3: _t->newPieceSelectionSeen((*reinterpret_cast< View*(*)>(_a[1]))); break;
        case 4: _t->logSceneChange((*reinterpret_cast< QRectF(*)>(_a[1]))); break;
        case 5: _t->setScene((*reinterpret_cast< Palapeli::Scene*(*)>(_a[1]))); break;
        case 6: _t->moveViewportBy((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 7: _t->zoomSliderInput((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->zoomIn(); break;
        case 9: _t->zoomOut(); break;
        case 10: _t->zoomBy((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->zoomTo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->startVictoryAnimation(); break;
        case 13: _t->adjustPointer(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< View* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< View* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (View::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::zoomLevelChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (View::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::zoomAdjustable)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (View::*_t)(Piece * , const QPointF & , View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::teleport)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (View::*_t)(View * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::newPieceSelectionSeen)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QRectF*>(_v) = _t->viewportRect(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setViewportRect(*reinterpret_cast< QRectF*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Palapeli::View::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_Palapeli__View.data,
      qt_meta_data_Palapeli__View,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__View.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int Palapeli::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Palapeli::View::zoomLevelChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Palapeli::View::zoomAdjustable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Palapeli::View::teleport(Piece * _t1, const QPointF & _t2, View * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Palapeli::View::newPieceSelectionSeen(View * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
