/****************************************************************************
** Meta object code from reading C++ file 'configdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/config/configdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__TriggerComboBox_t {
    QByteArrayData data[9];
    char stringdata0[135];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__TriggerComboBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__TriggerComboBox_t qt_meta_stringdata_Palapeli__TriggerComboBox = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Palapeli::TriggerComboBox"
QT_MOC_LITERAL(1, 26, 20), // "backgroundKeyChanged"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 13), // "backgroundKey"
QT_MOC_LITERAL(4, 62, 15), // "itemTypeChanged"
QT_MOC_LITERAL(5, 78, 7), // "isColor"
QT_MOC_LITERAL(6, 86, 16), // "setBackgroundKey"
QT_MOC_LITERAL(7, 103, 25), // "handleCurrentIndexChanged"
QT_MOC_LITERAL(8, 129, 5) // "index"

    },
    "Palapeli::TriggerComboBox\0"
    "backgroundKeyChanged\0\0backgroundKey\0"
    "itemTypeChanged\0isColor\0setBackgroundKey\0"
    "handleCurrentIndexChanged\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__TriggerComboBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       1,   46, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       4,    1,   37,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   40,    2, 0x0a /* Public */,
       7,    1,   43,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    8,

 // properties: name, type, flags
       3, QMetaType::QString, 0x00595103,

 // properties: notify_signal_id
       0,

       0        // eod
};

void Palapeli::TriggerComboBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TriggerComboBox *_t = static_cast<TriggerComboBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->backgroundKeyChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->itemTypeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setBackgroundKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->handleCurrentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TriggerComboBox::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TriggerComboBox::backgroundKeyChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TriggerComboBox::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TriggerComboBox::itemTypeChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        TriggerComboBox *_t = static_cast<TriggerComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->backgroundKey(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        TriggerComboBox *_t = static_cast<TriggerComboBox *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBackgroundKey(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Palapeli::TriggerComboBox::staticMetaObject = {
    { &KComboBox::staticMetaObject, qt_meta_stringdata_Palapeli__TriggerComboBox.data,
      qt_meta_data_Palapeli__TriggerComboBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::TriggerComboBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::TriggerComboBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__TriggerComboBox.stringdata0))
        return static_cast<void*>(this);
    return KComboBox::qt_metacast(_clname);
}

int Palapeli::TriggerComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Palapeli::TriggerComboBox::backgroundKeyChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Palapeli::TriggerComboBox::itemTypeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
