/****************************************************************************
** Meta object code from reading C++ file 'mouseinputbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/config/mouseinputbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mouseinputbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__MouseInputButton_t {
    QByteArrayData data[11];
    char stringdata0[149];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__MouseInputButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__MouseInputButton_t qt_meta_stringdata_Palapeli__MouseInputButton = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Palapeli::MouseInputButton"
QT_MOC_LITERAL(1, 27, 14), // "triggerChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 17), // "Palapeli::Trigger"
QT_MOC_LITERAL(4, 61, 10), // "newTrigger"
QT_MOC_LITERAL(5, 72, 14), // "triggerRequest"
QT_MOC_LITERAL(6, 87, 14), // "captureTrigger"
QT_MOC_LITERAL(7, 102, 12), // "clearTrigger"
QT_MOC_LITERAL(8, 115, 14), // "confirmTrigger"
QT_MOC_LITERAL(9, 130, 7), // "trigger"
QT_MOC_LITERAL(10, 138, 10) // "setTrigger"

    },
    "Palapeli::MouseInputButton\0triggerChanged\0"
    "\0Palapeli::Trigger\0newTrigger\0"
    "triggerRequest\0captureTrigger\0"
    "clearTrigger\0confirmTrigger\0trigger\0"
    "setTrigger"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__MouseInputButton[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    1,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   50,    2, 0x0a /* Public */,
       7,    0,   51,    2, 0x0a /* Public */,
       8,    1,   52,    2, 0x0a /* Public */,
      10,    1,   55,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    9,
    QMetaType::Void, 0x80000000 | 3,    9,

       0        // eod
};

void Palapeli::MouseInputButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MouseInputButton *_t = static_cast<MouseInputButton *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->triggerChanged((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        case 1: _t->triggerRequest((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        case 2: _t->captureTrigger(); break;
        case 3: _t->clearTrigger(); break;
        case 4: _t->confirmTrigger((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        case 5: _t->setTrigger((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MouseInputButton::*_t)(const Palapeli::Trigger & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseInputButton::triggerChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MouseInputButton::*_t)(const Palapeli::Trigger & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MouseInputButton::triggerRequest)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Palapeli::MouseInputButton::staticMetaObject = {
    { &QPushButton::staticMetaObject, qt_meta_stringdata_Palapeli__MouseInputButton.data,
      qt_meta_data_Palapeli__MouseInputButton,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::MouseInputButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::MouseInputButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__MouseInputButton.stringdata0))
        return static_cast<void*>(this);
    return QPushButton::qt_metacast(_clname);
}

int Palapeli::MouseInputButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Palapeli::MouseInputButton::triggerChanged(const Palapeli::Trigger & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Palapeli::MouseInputButton::triggerRequest(const Palapeli::Trigger & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
