/****************************************************************************
** Meta object code from reading C++ file 'gameplay.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/engine/gameplay.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameplay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__GamePlay_t {
    QByteArrayData data[46];
    char stringdata0[609];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__GamePlay_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__GamePlay_t qt_meta_stringdata_Palapeli__GamePlay = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Palapeli::GamePlay"
QT_MOC_LITERAL(1, 19, 14), // "reportProgress"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 10), // "pieceCount"
QT_MOC_LITERAL(4, 46, 13), // "originalCount"
QT_MOC_LITERAL(5, 60, 24), // "victoryAnimationFinished"
QT_MOC_LITERAL(6, 85, 10), // "playPuzzle"
QT_MOC_LITERAL(7, 96, 17), // "Palapeli::Puzzle*"
QT_MOC_LITERAL(8, 114, 6), // "puzzle"
QT_MOC_LITERAL(9, 121, 14), // "playPuzzleFile"
QT_MOC_LITERAL(10, 136, 4), // "path"
QT_MOC_LITERAL(11, 141, 18), // "actionGoCollection"
QT_MOC_LITERAL(12, 160, 19), // "actionTogglePreview"
QT_MOC_LITERAL(13, 180, 12), // "actionCreate"
QT_MOC_LITERAL(14, 193, 12), // "actionDelete"
QT_MOC_LITERAL(15, 206, 12), // "actionImport"
QT_MOC_LITERAL(16, 219, 12), // "actionExport"
QT_MOC_LITERAL(17, 232, 12), // "createHolder"
QT_MOC_LITERAL(18, 245, 12), // "deleteHolder"
QT_MOC_LITERAL(19, 258, 9), // "selectAll"
QT_MOC_LITERAL(20, 268, 15), // "rearrangePieces"
QT_MOC_LITERAL(21, 284, 12), // "actionZoomIn"
QT_MOC_LITERAL(22, 297, 13), // "actionZoomOut"
QT_MOC_LITERAL(23, 311, 13), // "restartPuzzle"
QT_MOC_LITERAL(24, 325, 9), // "configure"
QT_MOC_LITERAL(25, 335, 15), // "positionChanged"
QT_MOC_LITERAL(26, 351, 9), // "reduction"
QT_MOC_LITERAL(27, 361, 11), // "loadPreview"
QT_MOC_LITERAL(28, 373, 14), // "loadPuzzleFile"
QT_MOC_LITERAL(29, 388, 13), // "loadNextPiece"
QT_MOC_LITERAL(30, 402, 18), // "loadPiecePositions"
QT_MOC_LITERAL(31, 421, 13), // "finishLoading"
QT_MOC_LITERAL(32, 435, 21), // "playVictoryAnimation2"
QT_MOC_LITERAL(33, 457, 21), // "playVictoryAnimation3"
QT_MOC_LITERAL(34, 479, 15), // "updateSavedGame"
QT_MOC_LITERAL(35, 495, 20), // "changeSelectedHolder"
QT_MOC_LITERAL(36, 516, 12), // "PieceHolder*"
QT_MOC_LITERAL(37, 529, 1), // "h"
QT_MOC_LITERAL(38, 531, 8), // "teleport"
QT_MOC_LITERAL(39, 540, 6), // "Piece*"
QT_MOC_LITERAL(40, 547, 5), // "piece"
QT_MOC_LITERAL(41, 553, 8), // "scenePos"
QT_MOC_LITERAL(42, 562, 5), // "View*"
QT_MOC_LITERAL(43, 568, 4), // "view"
QT_MOC_LITERAL(44, 573, 11), // "closeHolder"
QT_MOC_LITERAL(45, 585, 23) // "handleNewPieceSelection"

    },
    "Palapeli::GamePlay\0reportProgress\0\0"
    "pieceCount\0originalCount\0"
    "victoryAnimationFinished\0playPuzzle\0"
    "Palapeli::Puzzle*\0puzzle\0playPuzzleFile\0"
    "path\0actionGoCollection\0actionTogglePreview\0"
    "actionCreate\0actionDelete\0actionImport\0"
    "actionExport\0createHolder\0deleteHolder\0"
    "selectAll\0rearrangePieces\0actionZoomIn\0"
    "actionZoomOut\0restartPuzzle\0configure\0"
    "positionChanged\0reduction\0loadPreview\0"
    "loadPuzzleFile\0loadNextPiece\0"
    "loadPiecePositions\0finishLoading\0"
    "playVictoryAnimation2\0playVictoryAnimation3\0"
    "updateSavedGame\0changeSelectedHolder\0"
    "PieceHolder*\0h\0teleport\0Piece*\0piece\0"
    "scenePos\0View*\0view\0closeHolder\0"
    "handleNewPieceSelection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__GamePlay[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      31,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  169,    2, 0x06 /* Public */,
       5,    0,  174,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,  175,    2, 0x0a /* Public */,
       9,    1,  178,    2, 0x0a /* Public */,
      11,    0,  181,    2, 0x0a /* Public */,
      12,    0,  182,    2, 0x0a /* Public */,
      13,    0,  183,    2, 0x0a /* Public */,
      14,    0,  184,    2, 0x0a /* Public */,
      15,    0,  185,    2, 0x0a /* Public */,
      16,    0,  186,    2, 0x0a /* Public */,
      17,    0,  187,    2, 0x0a /* Public */,
      18,    0,  188,    2, 0x0a /* Public */,
      19,    0,  189,    2, 0x0a /* Public */,
      20,    0,  190,    2, 0x0a /* Public */,
      21,    0,  191,    2, 0x0a /* Public */,
      22,    0,  192,    2, 0x0a /* Public */,
      23,    0,  193,    2, 0x0a /* Public */,
      24,    0,  194,    2, 0x0a /* Public */,
      25,    1,  195,    2, 0x0a /* Public */,
      27,    0,  198,    2, 0x08 /* Private */,
      28,    0,  199,    2, 0x08 /* Private */,
      29,    0,  200,    2, 0x08 /* Private */,
      30,    0,  201,    2, 0x08 /* Private */,
      31,    0,  202,    2, 0x08 /* Private */,
      32,    0,  203,    2, 0x08 /* Private */,
      33,    0,  204,    2, 0x08 /* Private */,
      34,    0,  205,    2, 0x08 /* Private */,
      35,    1,  206,    2, 0x08 /* Private */,
      38,    3,  209,    2, 0x08 /* Private */,
      44,    1,  216,    2, 0x08 /* Private */,
      45,    1,  219,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 36,   37,
    QMetaType::Void, 0x80000000 | 39, QMetaType::QPointF, 0x80000000 | 42,   40,   41,   43,
    QMetaType::Void, 0x80000000 | 36,   37,
    QMetaType::Void, 0x80000000 | 42,   43,

       0        // eod
};

void Palapeli::GamePlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GamePlay *_t = static_cast<GamePlay *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->reportProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->victoryAnimationFinished(); break;
        case 2: _t->playPuzzle((*reinterpret_cast< Palapeli::Puzzle*(*)>(_a[1]))); break;
        case 3: _t->playPuzzleFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->actionGoCollection(); break;
        case 5: _t->actionTogglePreview(); break;
        case 6: _t->actionCreate(); break;
        case 7: _t->actionDelete(); break;
        case 8: _t->actionImport(); break;
        case 9: _t->actionExport(); break;
        case 10: _t->createHolder(); break;
        case 11: _t->deleteHolder(); break;
        case 12: _t->selectAll(); break;
        case 13: _t->rearrangePieces(); break;
        case 14: _t->actionZoomIn(); break;
        case 15: _t->actionZoomOut(); break;
        case 16: _t->restartPuzzle(); break;
        case 17: _t->configure(); break;
        case 18: _t->positionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->loadPreview(); break;
        case 20: _t->loadPuzzleFile(); break;
        case 21: _t->loadNextPiece(); break;
        case 22: _t->loadPiecePositions(); break;
        case 23: _t->finishLoading(); break;
        case 24: _t->playVictoryAnimation2(); break;
        case 25: _t->playVictoryAnimation3(); break;
        case 26: _t->updateSavedGame(); break;
        case 27: _t->changeSelectedHolder((*reinterpret_cast< PieceHolder*(*)>(_a[1]))); break;
        case 28: _t->teleport((*reinterpret_cast< Piece*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2])),(*reinterpret_cast< View*(*)>(_a[3]))); break;
        case 29: _t->closeHolder((*reinterpret_cast< PieceHolder*(*)>(_a[1]))); break;
        case 30: _t->handleNewPieceSelection((*reinterpret_cast< View*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (GamePlay::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GamePlay::reportProgress)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GamePlay::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GamePlay::victoryAnimationFinished)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Palapeli::GamePlay::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Palapeli__GamePlay.data,
      qt_meta_data_Palapeli__GamePlay,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::GamePlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::GamePlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__GamePlay.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Palapeli::GamePlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void Palapeli::GamePlay::reportProgress(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Palapeli::GamePlay::victoryAnimationFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
