/****************************************************************************
** Meta object code from reading C++ file 'triggerlistview_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/palapeli-17.12.3/src/config/triggerlistview_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'triggerlistview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Palapeli__TriggerListDelegateWidget_t {
    QByteArrayData data[5];
    char stringdata0[81];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__TriggerListDelegateWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__TriggerListDelegateWidget_t qt_meta_stringdata_Palapeli__TriggerListDelegateWidget = {
    {
QT_MOC_LITERAL(0, 0, 35), // "Palapeli::TriggerListDelegate..."
QT_MOC_LITERAL(1, 36, 14), // "triggerChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 17), // "Palapeli::Trigger"
QT_MOC_LITERAL(4, 70, 10) // "newTrigger"

    },
    "Palapeli::TriggerListDelegateWidget\0"
    "triggerChanged\0\0Palapeli::Trigger\0"
    "newTrigger"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__TriggerListDelegateWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void Palapeli::TriggerListDelegateWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TriggerListDelegateWidget *_t = static_cast<TriggerListDelegateWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->triggerChanged((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TriggerListDelegateWidget::*_t)(const Palapeli::Trigger & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TriggerListDelegateWidget::triggerChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Palapeli::TriggerListDelegateWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Palapeli__TriggerListDelegateWidget.data,
      qt_meta_data_Palapeli__TriggerListDelegateWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::TriggerListDelegateWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::TriggerListDelegateWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__TriggerListDelegateWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Palapeli::TriggerListDelegateWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Palapeli::TriggerListDelegateWidget::triggerChanged(const Palapeli::Trigger & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_Palapeli__TriggerListDelegate_t {
    QByteArrayData data[6];
    char stringdata0[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Palapeli__TriggerListDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Palapeli__TriggerListDelegate_t qt_meta_stringdata_Palapeli__TriggerListDelegate = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Palapeli::TriggerListDelegate"
QT_MOC_LITERAL(1, 30, 14), // "triggerChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 18), // "slotTriggerChanged"
QT_MOC_LITERAL(4, 65, 17), // "Palapeli::Trigger"
QT_MOC_LITERAL(5, 83, 10) // "newTrigger"

    },
    "Palapeli::TriggerListDelegate\0"
    "triggerChanged\0\0slotTriggerChanged\0"
    "Palapeli::Trigger\0newTrigger"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Palapeli__TriggerListDelegate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   25,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,

       0        // eod
};

void Palapeli::TriggerListDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TriggerListDelegate *_t = static_cast<TriggerListDelegate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->triggerChanged(); break;
        case 1: _t->slotTriggerChanged((*reinterpret_cast< const Palapeli::Trigger(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Palapeli::Trigger >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TriggerListDelegate::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TriggerListDelegate::triggerChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Palapeli::TriggerListDelegate::staticMetaObject = {
    { &KWidgetItemDelegate::staticMetaObject, qt_meta_stringdata_Palapeli__TriggerListDelegate.data,
      qt_meta_data_Palapeli__TriggerListDelegate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Palapeli::TriggerListDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Palapeli::TriggerListDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Palapeli__TriggerListDelegate.stringdata0))
        return static_cast<void*>(this);
    return KWidgetItemDelegate::qt_metacast(_clname);
}

int Palapeli::TriggerListDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KWidgetItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Palapeli::TriggerListDelegate::triggerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
